@@ -254,10 +254,12 @@ class TwinThreadClient:
         return self.__post("/Model/UpdateTask", task)
 
     def get_input_data(self, task={}):
-        if isinstance(task, str):
-            task = task_string_to_context(task)
         if self.__input_data is not None:
             return self.__input_data
+
+        if isinstance(task, str):
+            task = task_string_to_context(task)
+
         return self.__post_data(
             "/Model/ExportPortData",
             {**task, "portId": "input,dataset", "useAttachment": False},
@@ -280,45 +282,51 @@ class TwinThreadClient:
     def _get_files(self):
         return self.__files
 
-    def get_organization_name(self):
-        return self.__post("/Organization/Open", {})["organization"]["name"]
-
-    def __save_local_file(self, file_type, name, contents):
-
-        blob_name = re.sub(r"\W+", "", name).lower()
-        mkdir("./tasks")
-        mkdir(f"./tasks/{self.__request_id}")
-        path = f"./tasks/{self.__request_id}/{blob_name}"
-
-        with open(path, "w") as f:
-            f.write(contents)
-
-        self.__files.append((file_type, name, path))
-
-    def __save_remote_file(self, type, name, contents):
-        blob_name = re.sub(r"\W+", "", name).lower()
-        file_suffix = ".json" if type == "json" else ".png" if type == "png" else ""
-        organization_name = "demo"  # this only works with masterdb right now.
-        blob_name = f"{self.__context['assetModelId']}_{self.__context['taskId']}_{blob_name}_org_i0{file_suffix}"
-
-        response_type = (
+    def __get_response_type(self, type):
+        return (
             "text/csv"
             if type is "table"
             else "application/json"
             if type is "json"
             else "arraybuffer"
         )
+
+    def __get_file_suffix(self, file_type):
+        return ".json" if file_type == "json" else ".png" if file_type == "png" else ""
+
+    def __write_file_contents(self, file_type, filename, contents):
+        response_type = self.__get_response_type(file_type)
+
         content_type = "b" if response_type is "arraybuffer" else ""
-
-        self.__auth_check()
-
-        filename = type + "_" + name
         file = open(filename, "w" + content_type)
         try:
             file.write(contents.read())
         except Exception as e:
             file.write(contents)
         file.close()
+
+    def __save_local_file(self, file_type, name, contents):
+        filename = re.sub(r"\W+", "", name).lower()
+        print(filename)
+        mkdir("./tasks")
+        mkdir(f"./tasks/{self.__request_id}")
+        path = f"./tasks/{self.__request_id}/{filename}"
+
+        self.__write_file_contents(file_type, path, contents)
+        self.__files.append((file_type, name, path))
+
+    def __save_remote_file(self, file_type, name, contents):
+        blob_name = re.sub(r"\W+", "", name).lower()
+        file_suffix = (
+            ".json" if file_type == "json" else ".png" if file_type == "png" else ""
+        )
+        blob_name = f"{self.__context['assetModelId']}_{self.__context['taskId']}_{blob_name}_org_i0{file_suffix}"
+
+        self.__auth_check()
+
+        filename = f"{type}_{name}"
+        self.__write_file_contents(file_type, filename, contents)
+
         from requests_toolbelt import MultipartEncoder
 
         m = MultipartEncoder(
