@@ -9,10 +9,11 @@ def test_task_encoding():
 
 
 def task_string_to_context(task_string):
-    [friendly, asset_model_id, task_id] = task_string.split("_")
+    [friendly, asset_model_id, operation_id, task_id] = task_string.split("_")
 
     return {
         "assetModelId": int(asset_model_id),
+        "operationId": int(operation_id),
         "taskId": int(task_id),
         "friendly": friendly,
     }
